# lumos-sat
Lumos provides tools for calculating the optical brightness of artificial satellites.

More specifically, Lumos allows the user to:
1. Fit analytic BRDFs (bidirectional reflectance distribution functions) to measured data.
2. Create brightness models of satellites.
3. Calculate satellite optical brightness for observers on the ground.

Possible use-cases include:
1. Allowing optical brightness to be used as a design constraint by satellite operators.
2. Lets astronomers plan observations based on when and where in the sky satellites are brightest.
